@@ -8,11 +8,9 @@
 #pragma once
 
 #include "filteractionwithtest.h"
+#include "mailcommon_private_export.h"
 
-namespace Phonon
-{
-class MediaObject;
-}
+class QMediaPlayer;
 
 namespace MailCommon
 {
@@ -20,7 +18,7 @@ namespace MailCommon
 // FilterActionPlaySound - execute command
 // Execute a sound
 //=============================================================================
-class FilterActionPlaySound : public FilterActionWithTest
+class MAILCOMMON_TESTS_EXPORT FilterActionPlaySound : public FilterActionWithTest
 {
     Q_OBJECT
 public:
@@ -35,6 +33,6 @@ public:
     [[nodiscard]] QString informationAboutNotValidAction() const override;
 
 private:
-    mutable Phonon::MediaObject *mPlayer = nullptr;
+    mutable QMediaPlayer *mPlayer = nullptr;
 };
 }
